DataStore

Struct DataStore 

pub struct DataStore<'lt> { /* private fields */ }

Implementations

Source

impl<'lt> DataStore<'lt>

pub fn load_mapping<P>(file_path: P, readonly: bool) -> Result<MemoryMap>
where P: AsRef<Path>,

pub unsafe fn get_header(mapping: &MemoryMap) -> &'lt mut DataStoreHeader

pub unsafe fn get_index(mapping: &MemoryMap) -> &'lt mut DataStoreIndex<'lt>

pub unsafe fn get_pager(mapping: &MemoryMap) -> &'lt mut DataStorePager<'lt>

pub fn load<P>(file_path: P, readonly: bool) -> Result<Self>
where P: AsRef<Path>,

pub const fn derive_index_bounds(total_len: usize) -> (usize, usize, usize)

store_length_in_bytes -> (index_offset, index_length, data_offset)

  • this should only be used when initializing a new DataStore
pub fn init<P>(file_path: &P) -> Result<Self>
where P: AsRef<Path>,

pub fn get_chunk_by_index(&self, index: usize) -> Result<MbufDataChunk<'_>>

pub fn calculate_index_bucket(hash: &Hash, index_modulo: u32) -> u32

pub fn get_bucket_index_chunk_by_hash( &self, hash: &Hash, ) -> Result<(u32, u32, Option<MbufDataChunk<'_>>)>

pub fn get_bucket_by_hash(&'lt self, hash: &Hash) -> Result<u32>

pub fn get_index_by_hash(&'lt self, hash: &Hash) -> Result<u32>

pub fn get_chunk_by_hash(&'lt self, hash: &Hash) -> Result<MbufDataChunk<'lt>>

pub fn get_chunk_by_hkey( &'lt self, key: &Hkey, ) -> Result<Resolved<MbufDataChunk<'lt>>>

pub fn put_opaque_chunk<C: DataChunk>( &self, opaque_chunk: &C, ) -> Result<(u32, u32, MbufDataChunk<'_>)>

Stores opaque data and returns a tuple containing the bucket, index, and DataChunk.

Arguments
  • opaque_chunk - A DataChunk representing the opaque data to be stored.
Returns

A Result containing:

  • Ok((bucket, index, datachunk)) on success:
    • bucket (u32): The hashmap index of the chunk.
    • index (u32): The chunk’s index withing the storage file.
    • datachunk (MbufDataChunk): The chunk of data that was stored.
  • Err(PsDataLakeError) on failure:
    • An error of type PsDataLakeError indicating the reason for failure.
pub fn put_encrypted_chunk<C: DataChunk>(&'lt self, chunk: &C) -> Result<Hkey>

pub fn put_large_chunk<C: DataChunk>(&'lt self, chunk: &C) -> Result<Hkey>

pub fn put_chunk<C: DataChunk>(&'lt self, chunk: &C) -> Result<Hkey>

pub fn put_large_blob(&'lt self, blob: &[u8]) -> Result<Hkey>

pub fn put_blob(&'lt self, blob: &[u8]) -> Result<Hkey>