pub struct DataStore<'lt> { /* private fields */ }Implementations
Sourceimpl<'lt> DataStore<'lt>
impl<'lt> DataStore<'lt>
pub fn load_mapping<P>(file_path: P, readonly: bool) -> Result<MemoryMap>
pub fn load<P>(file_path: P, readonly: bool) -> Result<Self>
Sourcepub const fn derive_index_bounds(total_len: usize) -> (usize, usize, usize)
pub const fn derive_index_bounds(total_len: usize) -> (usize, usize, usize)
store_length_in_bytes -> (index_offset, index_length, data_offset)
- this should only be used when initializing a new
DataStore
pub fn init<P>(file_path: &P) -> Result<Self>
pub fn get_chunk_by_index(&self, index: usize) -> Result<MbufDataChunk<'_>>
pub fn calculate_index_bucket(hash: &Hash, index_modulo: u32) -> u32
pub fn get_bucket_index_chunk_by_hash( &self, hash: &Hash, ) -> Result<(u32, u32, Option<MbufDataChunk<'_>>)>
pub fn get_bucket_by_hash(&'lt self, hash: &Hash) -> Result<u32>
pub fn get_index_by_hash(&'lt self, hash: &Hash) -> Result<u32>
pub fn get_chunk_by_hash(&'lt self, hash: &Hash) -> Result<MbufDataChunk<'lt>>
Sourcepub fn put_opaque_chunk<C: DataChunk>(
&self,
opaque_chunk: &C,
) -> Result<(u32, u32, MbufDataChunk<'_>)>
pub fn put_opaque_chunk<C: DataChunk>( &self, opaque_chunk: &C, ) -> Result<(u32, u32, MbufDataChunk<'_>)>
Stores opaque data and returns a tuple containing the bucket, index, and DataChunk.
Arguments
opaque_chunk- ADataChunkrepresenting the opaque data to be stored.
Returns
A Result containing:
Ok((bucket, index, datachunk))on success:bucket(u32): The hashmap index of the chunk.index(u32): The chunk’s index withing the storage file.datachunk(MbufDataChunk): The chunk of data that was stored.
Err(PsDataLakeError)on failure:- An error of type
PsDataLakeErrorindicating the reason for failure.
- An error of type
pub fn put_encrypted_chunk<C: DataChunk>(&'lt self, chunk: &C) -> Result<Hkey>
pub fn put_large_chunk<C: DataChunk>(&'lt self, chunk: &C) -> Result<Hkey>
pub fn put_chunk<C: DataChunk>(&'lt self, chunk: &C) -> Result<Hkey>
pub fn put_large_blob(&'lt self, blob: &[u8]) -> Result<Hkey>
pub fn put_blob(&'lt self, blob: &[u8]) -> Result<Hkey>